Modulatory Projections
======================

.. _ModulatoryProjection_Subtypes:

.. toctree::
   :maxdepth: 1

   LearningProjection
   ControlProjection
   GatingProjection

.. automodule:: psyneulink.core.components.projections.modulatory.modulatoryprojection
   :members: ModulatoryProjection_Base
   :exclude-members: Linear, random, Parameters
